act.qc.qcfilter.QCFilter
========================

.. currentmodule:: act.qc.qcfilter

.. autoclass:: QCFilter

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~QCFilter.__init__
      ~QCFilter.add_delta_test
      ~QCFilter.add_difference_test
      ~QCFilter.add_equal_to_test
      ~QCFilter.add_greater_equal_test
      ~QCFilter.add_greater_test
      ~QCFilter.add_inside_test
      ~QCFilter.add_less_equal_test
      ~QCFilter.add_less_test
      ~QCFilter.add_missing_value_test
      ~QCFilter.add_not_equal_to_test
      ~QCFilter.add_outside_test
      ~QCFilter.add_persistence_test
      ~QCFilter.add_test
      ~QCFilter.available_bit
      ~QCFilter.check_for_ancillary_qc
      ~QCFilter.compare_time_series_trends
      ~QCFilter.create_qc_variable
      ~QCFilter.datafilter
      ~QCFilter.get_masked_data
      ~QCFilter.get_qc_test_mask
      ~QCFilter.remove_test
      ~QCFilter.set_test
      ~QCFilter.unset_test
      ~QCFilter.update_ancillary_variable
   
   

   
   
   